pycryptosat: Python module of cryptominisat
===========================================

Description
-----------

   Build and install pycryptosat into appropriate venv.
   See cryptominisat for more details.

License
-------

MIT License


Upstream Contact
----------------

-  Authors: Mate Soos
-  Email: soos.mate@gmail.com
-  Website: http://www.msoos.org/
-  Releases: https://github.com/msoos/cryptominisat/releases
